@@ -1,7 +1,9 @@
 """Plotting functions."""
 from .autocorrplot import plot_autocorr
+from .bpvplot import plot_bpv
 from .compareplot import plot_compare
 from .densityplot import plot_density
+from .distcomparisonplot import plot_dist_comparison
 from .distplot import plot_dist
 from .elpdplot import plot_elpd
 from .energyplot import plot_energy
@@ -17,15 +19,14 @@ from .pairplot import plot_pair
 from .parallelplot import plot_parallel
 from .posteriorplot import plot_posterior
 from .ppcplot import plot_ppc
-from .distcomparisonplot import plot_dist_comparison
 from .rankplot import plot_rank
+from .separationplot import plot_separation
 from .traceplot import plot_trace
 from .violinplot import plot_violin
-from ..numeric_utils import _fast_kde_2d
-
 
 __all__ = [
     "plot_autocorr",
+    "plot_bpv",
     "plot_compare",
     "plot_density",
     "plot_dist",
@@ -37,7 +38,6 @@ __all__ = [
     "plot_hpd",
     "plot_joint",
     "plot_kde",
-    "_fast_kde_2d",
     "plot_khat",
     "plot_loo_pit",
     "plot_mcse",
@@ -49,4 +49,5 @@ __all__ = [
     "plot_rank",
     "plot_trace",
     "plot_violin",
+    "plot_separation",
 ]
