@@ -1,10 +1,9 @@
 """Matplotlib rankplot."""
 import matplotlib.pyplot as plt
 import numpy as np
-import scipy.stats
 
 from ....stats.density_utils import histogram
-from ...plot_utils import _scale_fig_size, make_label
+from ...plot_utils import _scale_fig_size, make_label, compute_ranks
 from . import backend_kwarg_defaults, backend_show, create_axes_grid
 
 
@@ -20,10 +19,32 @@ def plot_rank(
     colors,
     ref_line,
     labels,
+    ref_line_kwargs,
+    bar_kwargs,
+    vlines_kwargs,
+    marker_vlines_kwargs,
     backend_kwargs,
     show,
 ):
     """Matplotlib rankplot.."""
+    if ref_line_kwargs is None:
+        ref_line_kwargs = {}
+    ref_line_kwargs.setdefault("linestyle", "--")
+    ref_line_kwargs.setdefault("color", "k")
+
+    if bar_kwargs is None:
+        bar_kwargs = {}
+    bar_kwargs.setdefault("align", "center")
+
+    if vlines_kwargs is None:
+        vlines_kwargs = {}
+    vlines_kwargs.setdefault("lw", 2)
+
+    if marker_vlines_kwargs is None:
+        marker_vlines_kwargs = {}
+        marker_vlines_kwargs.setdefault("marker", "o")
+        marker_vlines_kwargs.setdefault("lw", 0)
+
     if backend_kwargs is None:
         backend_kwargs = {}
 
@@ -44,7 +65,7 @@ def plot_rank(
         )
 
     for ax, (var_name, selection, var_data) in zip(np.ravel(axes), plotters):
-        ranks = scipy.stats.rankdata(var_data, method="average").reshape(var_data.shape)
+        ranks = compute_ranks(var_data)
         bin_ary = np.histogram_bin_edges(ranks, bins=bins, range=(0, ranks.size))
         all_counts = np.empty((len(ranks), len(bin_ary) - 1))
         for idx, row in enumerate(ranks):
@@ -52,6 +73,8 @@ def plot_rank(
         gap = all_counts.max() * 1.05
         width = bin_ary[1] - bin_ary[0]
 
+        bar_kwargs.setdefault("width", width)
+        bar_kwargs.setdefault("edgecolor", ax.get_facecolor())
         # Center the bins
         bin_ary = (bin_ary[1:] + bin_ary[:-1]) / 2
 
@@ -63,23 +86,22 @@ def plot_rank(
                     bin_ary,
                     counts,
                     bottom=y_ticks[-1],
-                    width=width,
-                    align="center",
                     color=colors[idx],
-                    edgecolor=ax.get_facecolor(),
+                    **bar_kwargs,
                 )
                 if ref_line:
-                    ax.axhline(y=y_ticks[-1] + counts.mean(), linestyle="--", color="k")
+                    ax.axhline(y=y_ticks[-1] + counts.mean(), **ref_line_kwargs)
             if labels:
                 ax.set_ylabel("Chain", fontsize=ax_labelsize)
         elif kind == "vlines":
             ymin = all_counts.mean()
+
             for idx, counts in enumerate(all_counts):
-                ax.plot(bin_ary, counts, "o", color=colors[idx])
-                ax.vlines(bin_ary, ymin, counts, lw=2, colors=colors[idx])
+                ax.plot(bin_ary, counts, color=colors[idx], **marker_vlines_kwargs)
+                ax.vlines(bin_ary, ymin, counts, colors=colors[idx], **vlines_kwargs)
             ax.set_ylim(0, all_counts.mean() * 2)
             if ref_line:
-                ax.axhline(y=all_counts.mean(), linestyle="--", color="k")
+                ax.axhline(y=ymin, **ref_line_kwargs)
 
         if labels:
             ax.set_xlabel("Rank (all chains)", fontsize=ax_labelsize)
