@@ -1,10 +1,9 @@
 # pylint: disable=too-many-lines
 """Statistical functions in ArviZ."""
-import logging
 import warnings
 from collections import OrderedDict
 from copy import deepcopy
-from typing import List, Optional, Union
+from typing import TYPE_CHECKING, Any, Dict, List, Optional, Tuple, Union
 
 import numpy as np
 import pandas as pd
@@ -12,6 +11,7 @@ import scipy.stats as st
 import xarray as xr
 from scipy.optimize import minimize
 
+from arviz import _log
 from ..data import CoordSpec, DimSpec, InferenceData, convert_to_dataset, convert_to_inference_data
 from ..rcparams import rcParams
 from ..utils import Numba, _numba_var, _var_names, credible_interval_warning, get_coords
@@ -19,14 +19,16 @@ from .density_utils import get_bins as _get_bins
 from .density_utils import histogram as _histogram
 from .density_utils import kde as _kde
 from .diagnostics import _mc_error, _multichain_statistics, ess
-from .stats_utils import ELPDData, _circular_standard_deviation
+from .stats_utils import ELPDData, _circular_standard_deviation, smooth_data
 from .stats_utils import get_log_likelihood as _get_log_likelihood
 from .stats_utils import logsumexp as _logsumexp
 from .stats_utils import make_ufunc as _make_ufunc
 from .stats_utils import stats_variance_2d as svar
 from .stats_utils import wrap_xarray_ufunc as _wrap_xarray_ufunc
 
-_log = logging.getLogger(__name__)
+if TYPE_CHECKING:
+    from typing_extensions import Literal
+
 
 __all__ = [
     "apply_test_function",
@@ -43,7 +45,7 @@ __all__ = [
 
 
 def compare(
-    dataset_dict, ic=None, method="BB-pseudo-BMA", b_samples=1000, alpha=1, seed=None, scale=None
+    dataset_dict, ic=None, method="stacking", b_samples=1000, alpha=1, seed=None, scale=None
 ):
     r"""Compare models based on PSIS-LOO `loo` or WAIC `waic` cross-validation.
 
@@ -62,8 +64,8 @@ def compare(
     method: str
         Method used to estimate the weights for each model. Available options are:
 
-        - 'stacking' : stacking of predictive distributions.
-        - 'BB-pseudo-BMA' : (default) pseudo-Bayesian Model averaging using Akaike-type
+        - 'stacking' : (default) stacking of predictive distributions.
+        - 'BB-pseudo-BMA' : pseudo-Bayesian Model averaging using Akaike-type
           weighting. The weights are stabilized using the Bayesian bootstrap.
         - 'pseudo-BMA': pseudo-Bayesian Model averaging using Akaike-type
           weighting, without Bootstrap stabilization (not recommended).
@@ -141,17 +143,15 @@ def compare(
     waic : Compute the widely applicable information criterion.
 
     """
+    warnings.warn(
+        "The default method used to estimate the weights for each model,"
+        "has changed from BB-pseudo-BMA to stacking"
+    )
     names = list(dataset_dict.keys())
     scale = rcParams["stats.ic_scale"] if scale is None else scale.lower()
     if scale == "log":
         scale_value = 1
         ascending = False
-        warnings.warn(
-            "\nThe scale is now log by default. Use 'scale' argument or "
-            "'stats.ic_scale' rcParam if you rely on a specific value.\nA higher "
-            "log-score (or a lower deviance) indicates a model with better predictive "
-            "accuracy."
-        )
     else:
         if scale == "negative_log":
             scale_value = -1
@@ -175,6 +175,7 @@ def compare(
                 "warning",
                 "loo_scale",
             ],
+            dtype=np.float,
         )
         scale_col = "loo_scale"
     elif ic == "waic":
@@ -192,17 +193,18 @@ def compare(
                 "warning",
                 "waic_scale",
             ],
+            dtype=np.float,
         )
         scale_col = "waic_scale"
     else:
-        raise NotImplementedError("The information criterion {} is not supported.".format(ic))
+        raise NotImplementedError(f"The information criterion {ic} is not supported.")
 
     if method.lower() not in ["stacking", "bb-pseudo-bma", "pseudo-bma"]:
-        raise ValueError("The method {}, to compute weights, is not supported.".format(method))
+        raise ValueError(f"The method {method}, to compute weights, is not supported.")
 
-    ic_se = "{}_se".format(ic)
-    p_ic = "p_{}".format(ic)
-    ic_i = "{}_i".format(ic)
+    ic_se = f"{ic}_se"
+    p_ic = f"p_{ic}"
+    ic_i = f"{ic}_i"
 
     ics = pd.DataFrame()
     names = []
@@ -216,7 +218,7 @@ def compare(
     if method.lower() == "stacking":
         rows, cols, ic_i_val = _ic_matrix(ics, ic_i)
         exp_ic_i = np.exp(ic_i_val / scale_value)
-        last_col = cols - 1
+        km1 = cols - 1
 
         def w_fuller(weights):
             return np.concatenate((weights, [max(1.0 - np.sum(weights), 0.0)]))
@@ -230,18 +232,16 @@ def compare(
 
         def gradient(weights):
             w_full = w_fuller(weights)
-            grad = np.zeros(last_col)
-            for k in range(last_col - 1):
+            grad = np.zeros(km1)
+            for k in range(km1):
                 for i in range(rows):
-                    grad[k] += (exp_ic_i[i, k] - exp_ic_i[i, last_col]) / np.dot(
-                        exp_ic_i[i], w_full
-                    )
+                    grad[k] += (exp_ic_i[i, k] - exp_ic_i[i, km1]) / np.dot(exp_ic_i[i], w_full)
             return -grad
 
-        theta = np.full(last_col, 1.0 / cols)
-        bounds = [(0.0, 1.0) for _ in range(last_col)]
+        theta = np.full(km1, 1.0 / cols)
+        bounds = [(0.0, 1.0) for _ in range(km1)]
         constraints = [
-            {"type": "ineq", "fun": lambda x: 1.0 - np.sum(x)},
+            {"type": "ineq", "fun": lambda x: -np.sum(x) + 1.0},
             {"type": "ineq", "fun": np.sum},
         ]
 
@@ -261,7 +261,7 @@ def compare(
         z_bs = np.zeros_like(weights)
         for i in range(b_samples):
             z_b = np.dot(b_weighting[i], ic_i_val)
-            u_weights = np.exp((z_b - np.min(z_b)) / scale_value)
+            u_weights = np.exp((z_b - np.max(z_b)) / scale_value)
             z_bs[i] = z_b  # pylint: disable=unsupported-assignment-operation
             weights[i] = u_weights / np.sum(u_weights)
 
@@ -298,6 +298,8 @@ def compare(
                 res[scale_col],
             )
 
+    df_comp["rank"] = df_comp["rank"].astype(int)
+    df_comp["warning"] = df_comp["warning"].astype(bool)
     return df_comp.sort_values(by=ic, ascending=ascending)
 
 
@@ -330,6 +332,7 @@ def hpd(
     filter_vars=None,
     coords=None,
     max_modes=10,
+    dask_kwargs=None,
     **kwargs,
 ):
     """Pending deprecation. Please refer to :func:`~arviz.hdi`."""
@@ -348,6 +351,7 @@ def hpd(
         filter_vars,
         coords,
         max_modes,
+        dask_kwargs,
         **kwargs,
     )
 
@@ -363,6 +367,7 @@ def hdi(
     filter_vars=None,
     coords=None,
     max_modes=10,
+    dask_kwargs=None,
     **kwargs,
 ):
     """
@@ -377,16 +382,17 @@ def hdi(
         Any object that can be converted to an az.InferenceData object.
         Refer to documentation of az.convert_to_dataset for details.
     hdi_prob: float, optional
-        HDI prob for which interval will be computed. Defaults to ``stats.hdi_prob`` rcParam.
+        Prob for which the highest density interval will be computed. Defaults to
+        ``stats.hdi_prob`` rcParam.
     circular: bool, optional
         Whether to compute the hdi taking into account `x` is a circular variable
         (in the range [-np.pi, np.pi]) or not. Defaults to False (i.e non-circular variables).
         Only works if multimodal is False.
     multimodal: bool, optional
-        If true it may compute more than one hdi interval if the distribution is multimodal and the
+        If true it may compute more than one hdi if the distribution is multimodal and the
         modes are well separated.
     skipna: bool, optional
-        If true ignores nan values when computing the hdi interval. Defaults to false.
+        If true ignores nan values when computing the hdi. Defaults to false.
     group: str, optional
         Specifies which InferenceData group should be used to calculate hdi.
         Defaults to 'posterior'
@@ -403,6 +409,8 @@ def hdi(
         Specifies the subset over to calculate hdi.
     max_modes: int, optional
         Specifies the maximum number of modes for multimodal case.
+    dask_kwargs : dict, optional
+        Dask related kwargs passed to :func:`~arviz.wrap_xarray_ufunc`.
     kwargs: dict, optional
         Additional keywords passed to :func:`~arviz.wrap_xarray_ufunc`.
 
@@ -413,7 +421,7 @@ def hdi(
 
     See Also
     --------
-    plot_hdi : Plot HDI intervals for regression data.
+    plot_hdi : Plot highest density intervals for regression data.
     xarray.Dataset.quantile : Calculate quantiles of array for given probabilities.
 
     Examples
@@ -441,14 +449,15 @@ def hdi(
 
         In [1]: az.hdi(data, var_names=["mu", "theta"])
 
-    If we want to calculate the HDI over specified dimension of dataset,
-    we can pass `input_core_dims` by kwargs:
+    By default, ``hdi`` is calculated over the ``chain`` and ``draw`` dimensions. We can use the
+    ``input_core_dims`` argument of :func:`~arviz.wrap_xarray_ufunc` to change this. In this example
+    we calculate the HDI also over the ``school`` dimension:
 
     .. ipython::
 
-        In [1]: az.hdi(data, input_core_dims = [["chain"]])
+        In [1]: az.hdi(data, var_names="theta", input_core_dims = [["chain","draw", "school"]])
 
-    We can also calculate the hdi over a particular selection over all groups:
+    We can also calculate the hdi over a particular selection:
 
     .. ipython::
 
@@ -495,9 +504,9 @@ def hdi(
     ary = ary[var_names] if var_names else ary
 
     hdi_coord = xr.DataArray(["lower", "higher"], dims=["hdi"], attrs=dict(hdi_prob=hdi_prob))
-    hdi_data = _wrap_xarray_ufunc(func, ary, func_kwargs=func_kwargs, **kwargs).assign_coords(
-        {"hdi": hdi_coord}
-    )
+    hdi_data = _wrap_xarray_ufunc(
+        func, ary, func_kwargs=func_kwargs, dask_kwargs=dask_kwargs, **kwargs
+    ).assign_coords({"hdi": hdi_coord})
     hdi_data = hdi_data.dropna("mode", how="all") if multimodal else hdi_data
     return hdi_data.x.values if isarray else hdi_data
 
@@ -519,7 +528,7 @@ def _hdi(ary, hdi_prob, circular, skipna):
     ary = np.sort(ary)
     interval_idx_inc = int(np.floor(hdi_prob * n))
     n_intervals = n - interval_idx_inc
-    interval_width = ary[interval_idx_inc:] - ary[:n_intervals]
+    interval_width = np.subtract(ary[interval_idx_inc:], ary[:n_intervals], dtype=np.float_)
 
     if len(interval_width) == 0:
         raise ValueError("Too few elements for interval calculation. ")
@@ -567,7 +576,7 @@ def _hdi_multimodal(ary, hdi_prob, skipna, max_modes):
     for i, interval in enumerate(intervals_splitted):
         if i == max_modes:
             warnings.warn(
-                "found more modes than {0}, returning only the first {0} modes".format(max_modes)
+                f"found more modes than {max_modes}, returning only the first {max_modes} modes"
             )
             break
         if interval.size == 0:
@@ -799,7 +808,11 @@ def psislw(log_weights, reff=1.0):
     ufunc_kwargs = {"n_dims": 1, "n_output": 2, "ravel": False, "check_shape": False}
     kwargs = {"input_core_dims": [["sample"]], "output_core_dims": [["sample"], []]}
     log_weights, pareto_shape = _wrap_xarray_ufunc(
-        _psislw, log_weights, ufunc_kwargs=ufunc_kwargs, func_kwargs=func_kwargs, **kwargs
+        _psislw,
+        log_weights,
+        ufunc_kwargs=ufunc_kwargs,
+        func_kwargs=func_kwargs,
+        **kwargs,
     )
     if isinstance(log_weights, xr.DataArray):
         log_weights = log_weights.rename("log_weights").rename(sample="sample")
@@ -990,15 +1003,16 @@ def summary(
     data,
     var_names: Optional[List[str]] = None,
     filter_vars=None,
-    fmt: str = "wide",
-    kind: str = "all",
+    group=None,
+    fmt: "Literal['wide', 'long', 'xarray']" = "wide",
+    kind: "Literal['all', 'stats', 'diagnostics']" = "all",
     round_to=None,
     include_circ=None,
     circ_var_names=None,
     stat_funcs=None,
     extend=True,
     hdi_prob=None,
-    order="C",
+    order: "Literal['C', 'F']" = "C",
     index_origin=None,
     skipna=False,
     coords: Optional[CoordSpec] = None,
@@ -1021,6 +1035,9 @@ def summary(
         interpret var_names as substrings of the real variables names. If "regex",
         interpret var_names as regular expressions on the real variables names. A la
         `pandas.filter`.
+    group: str
+        Select a group for summary. Defaults to "posterior", "prior" or first group
+        in that order, depending what groups exists.
     fmt: {'wide', 'long', 'xarray'}
         Return format is either pandas.DataFrame {'wide', 'long'} or xarray.Dataset {'xarray'}.
     kind: {'all', 'stats', 'diagnostics'}
@@ -1046,8 +1063,8 @@ def summary(
         If True, use the statistics returned by ``stat_funcs`` in addition to, rather than in place
         of, the default statistics. This is only meaningful when ``stat_funcs`` is not None.
     hdi_prob: float, optional
-        HDI interval to compute. Defaults to 0.94. This is only meaningful when ``stat_funcs`` is
-        None.
+        Highest density interval to compute. Defaults to 0.94. This is only meaningful when
+        ``stat_funcs`` is None.
     order: {"C", "F"}
         If fmt is "wide", use either C or F unpacking order. Defaults to C.
     index_origin: int
@@ -1121,6 +1138,8 @@ def summary(
            ...: )
 
     """
+    _log.cache = []
+
     if include_circ:
         warnings.warn(
             "include_circ is deprecated and will be ignored. Use circ_var_names instead",
@@ -1142,19 +1161,38 @@ def summary(
     else:
         if not 1 >= hdi_prob > 0:
             raise ValueError("The value of hdi_prob should be in the interval (0, 1]")
-    posterior = convert_to_dataset(data, group="posterior", **extra_args)
-    var_names = _var_names(var_names, posterior, filter_vars)
-    posterior = posterior if var_names is None else posterior[var_names]
+
+    if isinstance(data, InferenceData):
+        if group is None:
+            if not data.groups():
+                raise TypeError("InferenceData does not contain any groups")
+            if "posterior" in data:
+                dataset = data["posterior"]
+            elif "prior" in data:
+                dataset = data["prior"]
+            else:
+                warnings.warn(f"Selecting first found group: {data.groups()[0]}")
+                dataset = data[data.groups()[0]]
+        else:
+            if group not in data.groups():
+                raise TypeError(f"InferenceData does not contain group: {group}")
+            dataset = data[group]
+    else:
+        dataset = convert_to_dataset(data, group="posterior", **extra_args)
+    var_names = _var_names(var_names, dataset, filter_vars)
+    dataset = dataset if var_names is None else dataset[var_names]
 
     fmt_group = ("wide", "long", "xarray")
     if not isinstance(fmt, str) or (fmt.lower() not in fmt_group):
-        raise TypeError("Invalid format: '{}'. Formatting options are: {}".format(fmt, fmt_group))
+        raise TypeError(f"Invalid format: '{fmt}'. Formatting options are: {fmt_group}")
 
     unpack_order_group = ("C", "F")
     if not isinstance(order, str) or (order.upper() not in unpack_order_group):
-        raise TypeError(
-            "Invalid order: '{}'. Unpacking options are: {}".format(order, unpack_order_group)
-        )
+        raise TypeError(f"Invalid order: '{order}'. Unpacking options are: {unpack_order_group}")
+
+    kind_group = ("all", "stats", "diagnostics")
+    if not isinstance(kind, str) or kind not in kind_group:
+        raise TypeError(f"Invalid kind: '{kind}'. Kind options are: {kind_group}")
 
     alpha = 1 - hdi_prob
 
@@ -1166,7 +1204,7 @@ def summary(
             for stat_func_name, stat_func in stat_funcs.items():
                 extra_metrics.append(
                     xr.apply_ufunc(
-                        _make_ufunc(stat_func), posterior, input_core_dims=(("chain", "draw"),)
+                        _make_ufunc(stat_func), dataset, input_core_dims=(("chain", "draw"),)
                     )
                 )
                 extra_metric_names.append(stat_func_name)
@@ -1174,17 +1212,17 @@ def summary(
             for stat_func in stat_funcs:
                 extra_metrics.append(
                     xr.apply_ufunc(
-                        _make_ufunc(stat_func), posterior, input_core_dims=(("chain", "draw"),)
+                        _make_ufunc(stat_func), dataset, input_core_dims=(("chain", "draw"),)
                     )
                 )
                 extra_metric_names.append(stat_func.__name__)
 
     if extend and kind in ["all", "stats"]:
-        mean = posterior.mean(dim=("chain", "draw"), skipna=skipna)
+        mean = dataset.mean(dim=("chain", "draw"), skipna=skipna)
 
-        sd = posterior.std(dim=("chain", "draw"), ddof=1, skipna=skipna)
+        sd = dataset.std(dim=("chain", "draw"), ddof=1, skipna=skipna)
 
-        hdi_post = hdi(posterior, hdi_prob=hdi_prob, multimodal=False, skipna=skipna)
+        hdi_post = hdi(dataset, hdi_prob=hdi_prob, multimodal=False, skipna=skipna)
         hdi_lower = hdi_post.sel(hdi="lower", drop=True)
         hdi_higher = hdi_post.sel(hdi="higher", drop=True)
 
@@ -1192,7 +1230,7 @@ def summary(
         nan_policy = "omit" if skipna else "propagate"
         circ_mean = xr.apply_ufunc(
             _make_ufunc(st.circmean),
-            posterior,
+            dataset,
             kwargs=dict(high=np.pi, low=-np.pi, nan_policy=nan_policy),
             input_core_dims=(("chain", "draw"),),
         )
@@ -1206,39 +1244,40 @@ def summary(
             kwargs_circ_std = dict(high=np.pi, low=-np.pi, nan_policy=nan_policy)
         circ_sd = xr.apply_ufunc(
             _make_ufunc(func),
-            posterior,
+            dataset,
             kwargs=kwargs_circ_std,
             input_core_dims=(("chain", "draw"),),
         )
 
         circ_mcse = xr.apply_ufunc(
             _make_ufunc(_mc_error),
-            posterior,
+            dataset,
             kwargs=dict(circular=True),
             input_core_dims=(("chain", "draw"),),
         )
 
-        circ_hdi = hdi(posterior, hdi_prob=hdi_prob, circular=True, skipna=skipna)
+        circ_hdi = hdi(dataset, hdi_prob=hdi_prob, circular=True, skipna=skipna)
         circ_hdi_lower = circ_hdi.sel(hdi="lower", drop=True)
         circ_hdi_higher = circ_hdi.sel(hdi="higher", drop=True)
 
     if kind in ["all", "diagnostics"]:
         mcse_mean, mcse_sd, ess_mean, ess_sd, ess_bulk, ess_tail, r_hat = xr.apply_ufunc(
             _make_ufunc(_multichain_statistics, n_output=7, ravel=False),
-            posterior,
+            dataset,
             input_core_dims=(("chain", "draw"),),
             output_core_dims=tuple([] for _ in range(7)),
         )
 
     # Combine metrics
-    metrics = []
-    metric_names = []
+    metrics: List[xr.Dataset] = []
+    metric_names: List[str] = []
     if extend:
-        metrics_names_ = (
+        metrics_: Tuple[xr.Dataset, ...]
+        metrics_names_: Tuple[str, ...] = (
             "mean",
             "sd",
-            "hdi_{:g}%".format(100 * alpha / 2),
-            "hdi_{:g}%".format(100 * (1 - alpha / 2)),
+            f"hdi_{100 * alpha / 2:g}%",
+            f"hdi_{100 * (1 - alpha / 2):g}%",
             "mcse_mean",
             "mcse_sd",
             "ess_mean",
@@ -1271,7 +1310,6 @@ def summary(
         metric_names.extend(metrics_names_)
 
     if circ_var_names:
-
         if kind != "diagnostics":
             for metric, circ_stat in zip(
                 # Replace only the first 5 statistics for their circular equivalent
@@ -1291,14 +1329,14 @@ def summary(
         dfs = []
         for var_name, values in joined.data_vars.items():
             if len(values.shape[1:]):
-                metric = list(values.metric.values)
+                index_metric = list(values.metric.values)
                 data_dict = OrderedDict()
                 for idx in np.ndindex(values.shape[1:] if order == "C" else values.shape[1:][::-1]):
                     if order == "F":
                         idx = tuple(idx[::-1])
-                    ser = pd.Series(values[(Ellipsis, *idx)].values, index=metric)
+                    ser = pd.Series(values[(Ellipsis, *idx)].values, index=index_metric)
                     key_index = ",".join(map(str, (i + index_origin for i in idx)))
-                    key = "{}[{}]".format(var_name, key_index)
+                    key = f"{var_name}[{key_index}]"
                     data_dict[key] = ser
                 df = pd.DataFrame.from_dict(data_dict, orient="index")
                 df = df.loc[list(data_dict.keys())]
@@ -1332,7 +1370,7 @@ def summary(
     return summary_df
 
 
-def waic(data, pointwise=None, var_name=None, scale=None):
+def waic(data, pointwise=None, var_name=None, scale=None, dask_kwargs=None):
     """Compute the widely applicable information criterion.
 
     Estimates the expected log pointwise predictive density (elpd) using WAIC. Also calculates the
@@ -1359,6 +1397,8 @@ def waic(data, pointwise=None, var_name=None, scale=None):
 
         A higher log-score (or a lower deviance or negative log_score) indicates a model with
         better predictive accuracy.
+    dask_kwargs : dict, optional
+        Dask related kwargs passed to :func:`~arviz.wrap_xarray_ufunc`.
 
     Returns
     -------
@@ -1416,6 +1456,7 @@ def waic(data, pointwise=None, var_name=None, scale=None):
         log_likelihood,
         func_kwargs={"b_inv": n_samples},
         ufunc_kwargs=ufunc_kwargs,
+        dask_kwargs=dask_kwargs,
         **kwargs,
     )
 
@@ -1496,6 +1537,8 @@ def loo_pit(idata=None, *, y=None, y_hat=None, log_weights=None):
         equal to y, thus, y must be str too.
     log_weights: array or DataArray
         Smoothed log_weights. It must have the same shape as ``y_hat``
+    dask_kwargs : dict, optional
+        Dask related kwargs passed to :func:`~arviz.wrap_xarray_ufunc`.
 
     Returns
     -------
@@ -1533,7 +1576,7 @@ def loo_pit(idata=None, *, y=None, y_hat=None, log_weights=None):
         if not all(isinstance(arg, (np.ndarray, xr.DataArray)) for arg in (y, y_hat, log_weights)):
             raise ValueError(
                 "all 3 y, y_hat and log_weights must be array or DataArray when idata is None "
-                "but they are of types {}".format([type(arg) for arg in (y, y_hat, log_weights)])
+                f"but they are of types {[type(arg) for arg in (y, y_hat, log_weights)]}"
             )
 
     else:
@@ -1545,17 +1588,15 @@ def loo_pit(idata=None, *, y=None, y_hat=None, log_weights=None):
             y_str = y
             y = idata.observed_data[y].values
         elif not isinstance(y, (np.ndarray, xr.DataArray)):
-            raise ValueError("y must be of types array, DataArray or str, not {}".format(type(y)))
+            raise ValueError(f"y must be of types array, DataArray or str, not {type(y)}")
         if isinstance(y_hat, str):
             y_hat = idata.posterior_predictive[y_hat].stack(sample=("chain", "draw")).values
         elif not isinstance(y_hat, (np.ndarray, xr.DataArray)):
-            raise ValueError(
-                "y_hat must be of types array, DataArray or str, not {}".format(type(y_hat))
-            )
+            raise ValueError(f"y_hat must be of types array, DataArray or str, not {type(y_hat)}")
         if log_weights is None:
             if y_str:
                 try:
-                    log_likelihood = _get_log_likelihood(idata, var_name=y)
+                    log_likelihood = _get_log_likelihood(idata, var_name=y_str)
                 except TypeError:
                     log_likelihood = _get_log_likelihood(idata)
             else:
@@ -1574,28 +1615,25 @@ def loo_pit(idata=None, *, y=None, y_hat=None, log_weights=None):
             log_weights = psislw(-log_likelihood, reff=reff)[0].values
         elif not isinstance(log_weights, (np.ndarray, xr.DataArray)):
             raise ValueError(
-                "log_weights must be None or of types array or DataArray, not {}".format(
-                    type(log_weights)
-                )
+                f"log_weights must be None or of types array or DataArray, not {type(log_weights)}"
             )
 
     if len(y.shape) + 1 != len(y_hat.shape):
         raise ValueError(
-            "y_hat must have 1 more dimension than y, but y_hat has {} dims and y has "
-            "{} dims".format(len(y.shape), len(y_hat.shape))
+            f"y_hat must have 1 more dimension than y, but y_hat has {len(y.shape)} dims and y has "
+            f"{len(y_hat.shape)} dims"
         )
 
     if y.shape != y_hat.shape[:-1]:
         raise ValueError(
-            "y has shape: {} which should be equal to y_hat shape (omitting the last "
-            "dimension): {}".format(y.shape, y_hat.shape)
+            f"y has shape: {y.shape} which should be equal to y_hat shape (omitting the last "
+            f"dimension): {y_hat.shape}"
         )
 
     if y_hat.shape != log_weights.shape:
         raise ValueError(
-            "y_hat and log_weights must have the same shape but have shapes {} and {}".format(
-                y_hat.shape, log_weights.shape
-            )
+            "y_hat and log_weights must have the same shape but have shapes "
+            f"{y_hat.shape,} and {log_weights.shape}"
         )
 
     kwargs = {
@@ -1605,7 +1643,17 @@ def loo_pit(idata=None, *, y=None, y_hat=None, log_weights=None):
     }
     ufunc_kwargs = {"n_dims": 1}
 
-    return _wrap_xarray_ufunc(_loo_pit, y, y_hat, log_weights, ufunc_kwargs=ufunc_kwargs, **kwargs)
+    if y.dtype.kind == "i" or y_hat.dtype.kind == "i":
+        y, y_hat = smooth_data(y, y_hat)
+
+    return _wrap_xarray_ufunc(
+        _loo_pit,
+        y,
+        y_hat,
+        log_weights,
+        ufunc_kwargs=ufunc_kwargs,
+        **kwargs,
+    )
 
 
 def _loo_pit(y, y_hat, log_weights):
@@ -1672,7 +1720,7 @@ def apply_test_function(
     func_kwargs: mapping, optional
         Passed as is to ``func``
     wrap_data_kwargs, wrap_pp_kwargs: mapping, optional
-        kwargs passed to ``az.stats.wrap_xarray_ufunc``. By default, some suitable input_core_dims
+        kwargs passed to :func:`~arviz.wrap_xarray_ufunc`. By default, some suitable input_core_dims
         are used.
     inplace: bool, optional
         If True, add the variables inplace, othewise, return a copy of idata with the variables
@@ -1712,9 +1760,7 @@ def apply_test_function(
 
     valid_groups = ("observed_data", "posterior_predictive", "both")
     if group not in valid_groups:
-        raise ValueError(
-            "Invalid group argument. Must be one of {} not {}.".format(valid_groups, group)
-        )
+        raise ValueError(f"Invalid group argument. Must be one of {valid_groups} not {group}.")
     if overwrite is None:
         overwrite = not inplace
 
@@ -1752,19 +1798,18 @@ def apply_test_function(
         out_name_group = out_name_data if grp == "observed_data" else out_name_pp
         wrap_group_kwargs = wrap_data_kwargs if grp == "observed_data" else wrap_pp_kwargs
         if not hasattr(out, grp):
-            raise ValueError("InferenceData object must have {} group".format(grp))
+            raise ValueError(f"InferenceData object must have {grp} group")
         if not overwrite and out_name_group in getattr(out, grp).data_vars:
             raise ValueError(
-                "Should overwrite: {} variable present in group {}, but overwrite is False".format(
-                    out_name_group, grp
-                )
+                f"Should overwrite: {out_name_group} variable present in group {grp},"
+                " but overwrite is False"
             )
         var_names.setdefault(
             grp, list(getattr(out, grp).data_vars) if both_var_names is None else both_var_names
         )
         in_group = getattr(out, grp)[var_names[grp]]
         if isinstance(in_group, xr.Dataset):
-            in_group = in_group.to_array(dim="{}_var".format(grp)).squeeze()
+            in_group = in_group.to_array(dim=f"{grp}_var").squeeze()
 
         if pointwise:
             out_group_shape = in_group.shape if out_group_shape is None else out_group_shape
