@@ -160,6 +160,20 @@ def test_dims_coords_extra_dims():
     assert len(coords["xy"]) == 20
 
 
+@pytest.mark.parametrize("shape", [(4, 20), (4, 20, 1)])
+def test_dims_coords_skip_event_dims(shape):
+    coords = {"x": np.arange(4), "y": np.arange(20), "z": np.arange(5)}
+    dims, coords = generate_dims_coords(
+        shape, "name", dims=["x", "y", "z"], coords=coords, skip_event_dims=True
+    )
+    assert "x" in dims
+    assert "y" in dims
+    assert "z" not in dims
+    assert len(coords["x"]) == 4
+    assert len(coords["y"]) == 20
+    assert "z" not in coords
+
+
 def test_make_attrs():
     extra_attrs = {"key": "Value"}
     attrs = make_attrs(attrs=extra_attrs)
@@ -593,6 +607,83 @@ class TestInferenceData:  # pylint: disable=too-many-public-methods
             test_xr_data = getattr(test_data, group)
             assert xr_data.equals(test_xr_data)
 
+    @pytest.mark.parametrize(
+        "kwargs",
+        (
+            {
+                "groups": "posterior",
+                "include_coords": True,
+                "include_index": True,
+                "index_origin": 0,
+            },
+            {
+                "groups": ["posterior", "sample_stats"],
+                "include_coords": False,
+                "include_index": True,
+                "index_origin": 0,
+            },
+            {
+                "groups": "posterior_groups",
+                "include_coords": True,
+                "include_index": False,
+                "index_origin": 1,
+            },
+        ),
+    )
+    def test_to_dataframe(self, kwargs):
+        idata = from_dict(
+            posterior={"a": np.random.randn(4, 100, 3, 4, 5), "b": np.random.randn(4, 100)},
+            sample_stats={"a": np.random.randn(4, 100, 3, 4, 5), "b": np.random.randn(4, 100)},
+            observed_data={"a": np.random.randn(3, 4, 5), "b": np.random.randn(4)},
+        )
+        test_data = idata.to_dataframe(**kwargs)
+        assert not test_data.empty
+        groups = kwargs.get("groups", idata._groups_all)  # pylint: disable=protected-access
+        for group in idata._groups_all:  # pylint: disable=protected-access
+            if "data" in group:
+                continue
+            assert test_data.shape == (
+                (4 * 100, 3 * 4 * 5 + 1 + 2)
+                if groups == "posterior"
+                else (4 * 100, (3 * 4 * 5 + 1) * 2 + 2)
+            )
+            if groups == "posterior":
+                if kwargs.get("include_coords", True) and kwargs.get("include_index", True):
+                    assert any(
+                        "[{},".format(kwargs.get("index_origin", 0)) in item[0]
+                        for item in test_data.columns
+                        if isinstance(item, tuple)
+                    )
+                if kwargs.get("include_coords", True):
+                    assert any(isinstance(item, tuple) for item in test_data.columns)
+                else:
+                    assert not any(isinstance(item, tuple) for item in test_data.columns)
+            else:
+                if not kwargs.get("include_index", True):
+                    assert all(
+                        item in test_data.columns
+                        for item in (("posterior", "a", 1, 1, 1), ("posterior", "b"))
+                    )
+            assert all(item in test_data.columns for item in ("chain", "draw"))
+
+    def test_to_dataframe_bad(self):
+        idata = from_dict(
+            posterior={"a": np.random.randn(4, 100, 3, 4, 5), "b": np.random.randn(4, 100)},
+            sample_stats={"a": np.random.randn(4, 100, 3, 4, 5), "b": np.random.randn(4, 100)},
+            observed_data={"a": np.random.randn(3, 4, 5), "b": np.random.randn(4)},
+        )
+        with pytest.raises(TypeError):
+            idata.to_dataframe(index_origin=2)
+
+        with pytest.raises(TypeError):
+            idata.to_dataframe(include_coords=False, include_index=False)
+
+        with pytest.raises(TypeError):
+            idata.to_dataframe(groups=["observed_data"])
+
+        with pytest.raises(KeyError):
+            idata.to_dataframe(groups=["invalid_group"])
+
     @pytest.mark.parametrize("use", (None, "args", "kwargs"))
     def test_map(self, use):
         idata = load_arviz_data("centered_eight")
@@ -821,6 +912,14 @@ def test_dict_to_dataset():
     assert set(dataset.b.coords) == {"chain", "draw", "c"}
 
 
+def test_dict_to_dataset_event_dims_error():
+    datadict = {"a": np.random.randn(1, 100, 10)}
+    coords = {"b": np.arange(10), "c": ["x", "y", "z"]}
+    msg = "different number of dimensions on data and dims"
+    with pytest.raises(ValueError, match=msg):
+        convert_to_dataset(datadict, coords=coords, dims={"a": ["b", "c"]})
+
+
 def test_convert_to_dataset_idempotent():
     first = convert_to_dataset(np.random.randn(100))
     second = convert_to_dataset(first)
