@@ -192,7 +192,7 @@ def test_plot_separation(kwargs):
         {"lines": [("mu", {}, [1, 2])]},
         {"lines": [("mu", {}, 8)]},
         {"circ_var_names": ["mu"]},
-        {"circ_var_units": "degrees"},
+        {"circ_var_names": ["mu"], "circ_var_units": "degrees"},
     ],
 )
 def test_plot_trace(models, kwargs):
@@ -394,11 +394,14 @@ def test_plot_joint_bad(models):
         {"is_circular": True},
         {"is_circular": "radians"},
         {"is_circular": "degrees"},
+        {"adaptive": True},
     ],
 )
 def test_plot_kde(continuous_model, kwargs):
     axes = plot_kde(continuous_model["x"], continuous_model["y"], **kwargs)
+    axes1 = plot_kde(continuous_model["x"], continuous_model["y"], **kwargs)
     assert axes
+    assert axes is axes1
 
 
 @pytest.mark.parametrize("shape", [(8,), (8, 8), (8, 8, 8)])
@@ -442,7 +445,9 @@ def test_plot_kde_cumulative(continuous_model, kwargs):
 )
 def test_plot_dist(continuous_model, kwargs):
     axes = plot_dist(continuous_model["x"], **kwargs)
+    axes1 = plot_dist(continuous_model["x"], **kwargs)
     assert axes
+    assert axes is axes1
 
 
 def test_plot_dist_hist(data_random):
@@ -585,7 +590,8 @@ def test_plot_pair_shapes(marginals, max_subplots):
 @pytest.mark.parametrize("kind", ["kde", "cumulative", "scatter"])
 @pytest.mark.parametrize("alpha", [None, 0.2, 1])
 @pytest.mark.parametrize("animated", [False, True])
-def test_plot_ppc(models, kind, alpha, animated):
+@pytest.mark.parametrize("observed", [True, False])
+def test_plot_ppc(models, kind, alpha, animated, observed):
     if animation and not animation.writers.is_available("ffmpeg"):
         pytest.skip("matplotlib animations within ArviZ require ffmpeg")
     animation_kwargs = {"blit": False}
@@ -593,6 +599,7 @@ def test_plot_ppc(models, kind, alpha, animated):
         models.model_1,
         kind=kind,
         alpha=alpha,
+        observed=observed,
         animated=animated,
         animation_kwargs=animation_kwargs,
         random_seed=3,
@@ -846,8 +853,19 @@ def test_plot_autocorr_var_names(models, var_names):
         {"var_names": "mu"},
         {"var_names": ("mu", "tau"), "coords": {"theta_dim_0": [0, 1]}},
         {"var_names": "mu", "ref_line": True},
+        {
+            "var_names": "mu",
+            "ref_line_kwargs": {"lw": 2, "color": "C2"},
+            "bar_kwargs": {"width": 0.7},
+        },
         {"var_names": "mu", "ref_line": False},
         {"var_names": "mu", "kind": "vlines"},
+        {
+            "var_names": "mu",
+            "kind": "vlines",
+            "vlines_kwargs": {"lw": 0},
+            "marker_vlines_kwargs": {"lw": 3},
+        },
     ],
 )
 def test_plot_rank(models, kwargs):
@@ -914,6 +932,14 @@ def test_plot_posterior_point_estimates(models, point_estimate):
     assert axes.size == 2
 
 
+def test_plot_posterior_skipna():
+    sample = np.linspace(0, 1)
+    sample[:10] = np.nan
+    plot_posterior({"a": sample}, skipna=True)
+    with pytest.raises(ValueError):
+        plot_posterior({"a": sample}, skipna=False)
+
+
 @pytest.mark.parametrize(
     "kwargs", [{"insample_dev": False}, {"plot_standard_error": False}, {"plot_ic_diff": False}]
 )
@@ -924,16 +950,6 @@ def test_plot_compare(models, kwargs):
     assert axes
 
 
-def test_plot_compare_manual(models):
-    """Test compare plot without scale column"""
-    model_compare = compare({"Model 1": models.model_1, "Model 2": models.model_2})
-
-    # remove "scale" column
-    del model_compare["loo_scale"]
-    axes = plot_compare(model_compare)
-    assert axes
-
-
 def test_plot_compare_no_ic(models):
     """Check exception is raised if model_compare doesn't contain a valid information criterion"""
     model_compare = compare({"Model 1": models.model_1, "Model 2": models.model_2})
@@ -1122,7 +1138,12 @@ def test_plot_elpd_one_model(models):
         {"color": "obs_dim", "legend": True, "hover_label": True},
         {"color": "blue", "coords": {"obs_dim": slice(2, 4)}},
         {"color": np.random.uniform(size=8), "show_bins": True},
-        {"color": np.random.uniform(size=(8, 3)), "show_bins": True, "annotate": True},
+        {
+            "color": np.random.uniform(size=(8, 3)),
+            "show_bins": True,
+            "show_hlines": True,
+            "threshold": 1,
+        },
     ],
 )
 @pytest.mark.parametrize("input_type", ["elpd_data", "data_array", "array"])
@@ -1149,7 +1170,12 @@ def test_plot_khat(models, input_type, kwargs):
         {"color": "dim2", "legend": True, "hover_label": True},
         {"color": "blue", "coords": {"dim2": slice(2, 4)}},
         {"color": np.random.uniform(size=35), "show_bins": True},
-        {"color": np.random.uniform(size=(35, 3)), "show_bins": True, "annotate": True},
+        {
+            "color": np.random.uniform(size=(35, 3)),
+            "show_bins": True,
+            "show_hlines": True,
+            "threshold": 1,
+        },
     ],
 )
 @pytest.mark.parametrize("input_type", ["elpd_data", "data_array", "array"])
@@ -1171,9 +1197,9 @@ def test_plot_khat_multidim(multidim_models, input_type, kwargs):
     assert axes
 
 
-def test_plot_khat_annotate():
+def test_plot_khat_threshold():
     khats = np.array([0, 0, 0.6, 0.6, 0.8, 0.9, 0.9, 2, 3, 4, 1.5])
-    axes = plot_khat(khats, annotate=True)
+    axes = plot_khat(khats, threshold=1)
     assert axes
 
 
